"use strict";
exports.__esModule = true;
var graphql_1 = require("graphql");
exports.GraphQLScalarTypeArray = [
    "Boolean",
    "Int",
    "Float",
    "String",
    "ID",
    "DateTime"
];
function getTSTypeFromGraphQLType(type) {
    if (type === "Int" || type === "Float") {
        return "number";
    }
    if (type === "Boolean") {
        return "boolean";
    }
    if (type === "String" || type === "ID" || type === "DateTime") {
        return "string";
    }
}
exports.getTSTypeFromGraphQLType = getTSTypeFromGraphQLType;
function extractGraphQLTypes(schema) {
    var types = [];
    graphql_1.visit(schema, {
        ObjectTypeDefinition: function (node) {
            var fields = [];
            graphql_1.visit(node.fields, {
                FieldDefinition: function (fieldNode) {
                    var fieldType = {};
                    graphql_1.visit(fieldNode.type, {
                        NonNullType: function (nonNullTypeNode) {
                            fieldType.isRequired = true;
                        },
                        ListType: function (listTypeNode) {
                            fieldType.isArray = true;
                        },
                        NamedType: function (namedTypeNode) {
                            fieldType.name = namedTypeNode.name.value;
                        }
                    });
                    var fieldArguments = [];
                    graphql_1.visit(fieldNode.arguments, {
                        InputValueDefinition: function (inputValueDefinitionNode) {
                            var argumentType = {};
                            graphql_1.visit(inputValueDefinitionNode.type, {
                                NonNullType: function (nonNullTypeNode) {
                                    argumentType.isRequired = true;
                                },
                                ListType: function (listTypeNode) {
                                    argumentType.isArray = true;
                                },
                                NamedType: function (namedTypeNode) {
                                    argumentType.name = namedTypeNode.name.value;
                                }
                            });
                            fieldArguments.push({
                                name: inputValueDefinitionNode.name.value,
                                type: argumentType
                            });
                        }
                    });
                    fields.push({
                        name: fieldNode.name.value,
                        type: fieldType,
                        arguments: fieldArguments
                    });
                }
            });
            types.push({
                name: node.name.value,
                fields: fields
            });
        }
    });
    return types;
}
exports.extractGraphQLTypes = extractGraphQLTypes;
//# sourceMappingURL=source-helper.js.map